1
  Deren A. R. Eaton. Toytree: A minimalist tree visualization and manipulation library for Python. Methods in Ecology and Evolution, 11:187–191, 2020. doi:10.1111/2041-210X.13313.
2
  David M. Emms and Steven Kelly. Orthofinder: phylogenetic orthology inference for comparative genomics. Genome Biology, 20(1):238, 2019. URL: https://doi.org/10.1186/s13059-019-1832-y, doi:10.1186/s13059-019-1832-y.
3
  Diep Thi Hoang, Olga Chernomor, Arndt von Haeseler, Bui Quang Minh, and Le Sy Vinh. UFBoot2: Improving the Ultrafast Bootstrap Approximation. Molecular Biology and Evolution, 35(2):518–522, 10 2017. URL: https://doi.org/10.1093/molbev/msx281, arXiv:https://academic.oup.com/mbe/article-pdf/35/2/518/24367824/msx281.pdf, doi:10.1093/molbev/msx281.
4
  Subha Kalyaanamoorthy, Bui Quang Minh, Thomas K F Wong, Arndt von Haeseler, and Lars S Jermiin. Modelfinder: fast model selection for accurate phylogenetic estimates. Nature Methods, 14(6):587–589, 2017. URL: https://doi.org/10.1038/nmeth.4285, doi:10.1038/nmeth.4285.
5
  Kazutaka Katoh and Daron M. Standley. MAFFT Multiple Sequence Alignment Software Version 7: Improvements in Performance and Usability. Molecular Biology and Evolution, 30(4):772–780, 01 2013. URL: https://doi.org/10.1093/molbev/mst010, arXiv:https://academic.oup.com/mbe/article-pdf/30/4/772/6420419/mst010.pdf, doi:10.1093/molbev/mst010.
6
  Bui Quang Minh, Heiko A Schmidt, Olga Chernomor, Dominik Schrempf, Michael D Woodhams, Arndt von Haeseler, and Robert Lanfear. IQ-TREE 2: New Models and Efficient Methods for Phylogenetic Inference in the Genomic Era. Molecular Biology and Evolution, 37(5):1530–1534, 02 2020. URL: https://doi.org/10.1093/molbev/msaa015, arXiv:https://academic.oup.com/mbe/article-pdf/37/5/1530/33386032/msaa015.pdf, doi:10.1093/molbev/msaa015.
7
  Jacob L Steenwyk, III Buida, Thomas J, Abigail L Labella, Yuanning Li, Xing-Xing Shen, and Antonis Rokas. PhyKIT: a broadly applicable UNIX shell toolkit for processing and analyzing phylogenomic data. Bioinformatics, 37(16):2325–2331, 02 2021. URL: https://doi.org/10.1093/bioinformatics/btab096, arXiv:https://academic.oup.com/bioinformatics/article-pdf/37/16/2325/39948152/btab096.pdf, doi:10.1093/bioinformatics/btab096.
8
  Jacob L. Steenwyk, Thomas J. Buida, Carla Gonçalves, Dayna C. Goltz, Grace Morales, Matthew E. Mead, Abigail L. LaBella, Christina M. Chavez, Jonathan E. Schmitz, Maria Hadjifrangiskou, Yuanning Li, and Antonis Rokas. BioKIT: a versatile toolkit for processing and analyzing diverse types of sequence data. biorxiv, oct 2021. URL: https://doi.org/10.1101%2F2021.10.02.462868, doi:10.1101/2021.10.02.462868.
9
  Jacob L. Steenwyk, Thomas J. Buida, III, Yuanning Li, Xing-Xing Shen, and Antonis Rokas. Clipkit: a multiple sequence alignment trimming software for accurate phylogenomic inference. PLOS Biology, 18(12):1–17, 12 2020. URL: https://doi.org/10.1371/journal.pbio.3001007, doi:10.1371/journal.pbio.3001007.
10
  Chao Zhang, Maryam Rabiee, Erfan Sayyari, and Siavash Mirarab. Astral-iii: polynomial time species tree reconstruction from partially resolved gene trees. BMC Bioinformatics, 19(6):153, 2018. URL: https://doi.org/10.1186/s12859-018-2129-y, doi:10.1186/s12859-018-2129-y.